@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Test::Warnings; # git description: v0.034-3-gbad3366
+package Test::Warnings; # git description: v0.035-3-g0d65702
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Test for warnings and the lack of them
 # KEYWORDS: testing tests warnings
 
-our $VERSION = '0.035';
+our $VERSION = '0.036';
 
 use parent 'Exporter';
 use Test::Builder;
@@ -41,6 +41,14 @@ sub import {
     $report_warnings = exists $names{':report_warnings'};
 
     delete @names{qw(:no_end_test :fail_on_warning :report_warnings)};
+
+    {
+        my $callpkg = caller(1);
+        no strict 'refs';
+        no warnings 'once';
+        undef *{$callpkg.'::done_testing'} if *{$callpkg.'::done_testing'}{CODE};
+    }
+
     __PACKAGE__->export_to_level(1, $class, keys %names);
 }
 
@@ -236,7 +244,7 @@ Test::Warnings - Test for warnings and the lack of them
 
 =head1 VERSION
 
-version 0.035
+version 0.036
 
 =head1 SYNOPSIS
 
