@@ -5,13 +5,20 @@ package Test2::Warnings;
 # ABSTRACT: Test for warnings and the lack of them
 # KEYWORDS: testing tests warnings Test2
 
-our $VERSION = '0.035';
+our $VERSION = '0.036';
 
 use base qw(Exporter);
 use Import::Into;
 use Test::Warnings;
 
 sub import {
+  {
+    my $callpkg = caller(1);
+    no strict 'refs';
+    no warnings 'once';
+    undef *{$callpkg.'::done_testing'} if *{$callpkg.'::done_testing'}{CODE};
+  }
+
   shift->export_to_level(1);
   Test::Warnings->import::into(1);
 }
@@ -30,7 +37,7 @@ Test2::Warnings - Test for warnings and the lack of them
 
 =head1 VERSION
 
-version 0.035
+version 0.036
 
 =head1 SYNOPSIS
 
